import { BaseResponse } from "./BaseResponse";
export declare namespace Kick {
    interface CurrentViewers {
        livestream_id: number;
        viewers: number;
    }
    interface Chatroom {
        id: number;
        chatable_type: string;
        channel_id: number;
        created_at: string;
        updated_at: string;
        chat_mode_old: string;
        chat_mode: string;
        slow_mode: boolean;
        chatable_id: number;
    }
    interface ChannelUser {
        id: number;
        username: string;
        agreed_to_terms: boolean;
        email_verified_at: string;
        bio: string;
        country: string;
        state: string;
        city: string;
        instagram: string;
        twitter: string;
        youtube: string;
        discord: string;
        tiktok: string;
        facebook: string;
        birthdate: string;
        profile_pic: string;
    }
    interface AscendingLink {
        id: number;
        channel_id: number;
        description: string;
        link: string;
        created_at: string;
        updated_at: string;
        order: number;
        title: string;
    }
    interface Plan {
        id: number;
        channel_id: number;
        stripe_plan_id: string;
        amount: string;
        created_at: string;
        updated_at: string;
    }
    interface PreviousLivestream {
        id: number;
        slug: string;
        channel_id: number;
        created_at: string;
        session_title: string;
        is_live: boolean;
        risk_level_id: any;
        source?: string;
        twitch_channel: any;
        duration: number;
        language: string;
        is_mature: boolean;
        viewer_count: number;
        thumbnail: Thumbnail2;
        views: number;
        tags: any[];
        categories: Category4[];
        video: Video;
    }
    interface Thumbnail2 {
        src: string;
        srcset: string;
    }
    interface Category4 {
        id: number;
        category_id: number;
        name: string;
        slug: string;
        tags: string[];
        description: any;
        deleted_at: any;
        banner: Banner2;
        category: Category5;
    }
    interface Banner2 {
        responsive: string;
        url: string;
    }
    interface Category5 {
        id: number;
        name: string;
        slug: string;
        icon: string;
    }
    interface Video {
        id: number;
        live_stream_id: number;
        slug: any;
        thumb: any;
        s3: any;
        trading_platform_id: any;
        created_at: string;
        updated_at: string;
        uuid: string;
        views: number;
        deleted_at: any;
    }
    interface Verified {
        id: number;
        channel_id: number;
        created_at: string;
        updated_at: string;
    }
    interface SubscriberBadge {
        id: number;
        channel_id: number;
        months: number;
        badge_image: BadgeImage;
    }
    interface BadgeImage {
        srcset: string;
        src: string;
    }
    interface BannerImage {
        responsive: string;
        url: string;
    }
    interface RecentCategory {
        id: number;
        category_id: number;
        name: string;
        slug: string;
        tags: string[];
        description: any;
        deleted_at: any;
        banner: Banner;
        category: Category;
    }
    interface Banner {
        responsive: string;
        url: string;
    }
    interface Category {
        id: number;
        name: string;
        slug: string;
        icon: string;
    }
    interface Livestream {
        id: number;
        slug: string;
        channel_id: number;
        created_at: string;
        session_title: string;
        is_live: boolean;
        risk_level_id: any;
        source: any;
        twitch_channel: any;
        duration: number;
        language: string;
        is_mature: boolean;
        viewer_count: number;
        thumbnail: Thumbnail;
        viewers: number;
        categories: Category2[];
        tags: any[];
    }
    interface Thumbnail {
        responsive: string;
        url: string;
    }
    interface Category2 {
        id: number;
        category_id: number;
        name: string;
        slug: string;
        tags: string[];
        description: any;
        deleted_at: any;
        category: Category3;
    }
    interface Category3 {
        id: number;
        name: string;
        slug: string;
        icon: string;
    }
    interface GeneratedConversions {
        fullsize: boolean;
        medium: boolean;
    }
    interface CustomProperties {
        generated_conversions: GeneratedConversions;
    }
    interface Medum {
        id: number;
        model_type: string;
        model_id: number;
        collection_name: string;
        name: string;
        file_name: string;
        mime_type: string;
        disk: string;
        size: number;
        manipulations: any[];
        custom_properties: CustomProperties;
        responsive_images: any[];
        order_column: number;
        created_at: string;
        updated_at: string;
        uuid: string;
        conversions_disk: string;
    }
    interface ChannelInfo {
        id: number;
        user_id: number;
        slug: string;
        playback_url: string;
        name_updated_at: any;
        vod_enabled: boolean;
        subscription_enabled: boolean;
        cf_rate_limiter: string;
        followersCount: number;
        subscriber_badges: SubscriberBadge[];
        banner_image: BannerImage;
        recent_categories: RecentCategory[];
        livestream: Livestream;
        role: any;
        muted: boolean;
        follower_badges: any[];
        offline_banner_image: any;
        can_host: boolean;
        user: ChannelUser;
        chatroom: Chatroom;
        ascending_links: AscendingLink[];
        plan: Plan;
        previous_livestreams: PreviousLivestream[];
        verified: Verified;
        media: Medum[];
    }
    interface User {
        id: number;
        username: string;
        slug: string;
        profile_pic: string | null;
        is_staff: boolean;
        is_channel_owner: boolean;
        is_moderator: boolean;
        badges: Badge[];
        following_since: string;
        subscribed_for: number;
        banned: any;
    }
    interface Sender {
        id: number;
        username: string;
        slug: string;
        identity: Identity;
    }
    interface Identity {
        color: string;
        badges: Badge[];
    }
    interface Badge {
        type: string;
        text: string;
        count?: number;
    }
    interface ChatMessageData {
        id: string;
        chatroom_id: number;
        content: string;
        type: string;
        created_at: string;
        sender: Sender;
    }
    interface FollowersUpdateData {
        channel_id: number;
        created_at: number;
        followed: boolean;
        followersCount: number;
        username: null | string;
    }
    interface LuckyUsersWhoGotGiftSubscriptionsEventData {
        channel: ChannelInfo;
        gifter_username: string;
        usernames: string[];
    }
    interface GiftsLeaderboardUpdatedData {
        channel: ChannelInfo;
        gifted_quantity: number;
        gifter_id: number;
        leaderboard: {
            quantity: number;
            username: string;
            user_id: number;
        }[];
    }
    interface ChatMessageReact {
        channel: string;
        data: string;
        event: 'App\\Events\\ChatMessageReact';
    }
    interface ChatMessageEvent {
        channel: string;
        data: string;
        event: 'App\\Events\\ChatMessageEvent';
    }
    interface SubscriptionSucceeded {
        channel: string;
        data: string;
        event: 'pusher_internal:subscription_succeeded';
    }
    interface ConnectionEstablished {
        channel: string;
        data: string;
        event: 'pusher:connection_established';
    }
    interface FollowersUpdate {
        channel: string;
        data: string;
        event: 'App\\Events\\FollowersUpdated';
    }
    interface ISLiveStream {
        id: number;
        channel_id: number;
        session_title: string;
        source: any;
        created_at: string;
    }
    interface StreamerIsLiveData {
        livestream: ISLiveStream;
    }
    interface StreamerIsLive {
        event: 'App\\Events\\StreamerIsLive';
        data: string;
        channel: string;
    }
    interface ChatMessageDeleted {
        channel: string;
        data: string;
        event: 'App\\Events\\ChatMessageDeletedEvent';
    }
    interface LuckyUsersWhoGotGiftSubscriptionsEvent {
        channel: string;
        data: string;
        event: 'App\\Events\\LuckyUsersWhoGotGiftSubscriptionsEvent';
    }
    interface GiftsLeaderboardUpdated {
        channel: string;
        data: string;
        event: 'App\\Events\\GiftsLeaderboardUpdated';
    }
    interface DeletedMessage {
        id: string;
        deleted_by: number;
        chatroom_id: string;
    }
    interface ChatMessageDeletedEventData {
        deletedMessage: DeletedMessage;
    }
    interface ChatMessageDeletedEvent {
        event: 'App\\Events\\ChatMessageDeletedEvent';
        channel: string;
        data: string;
    }
    interface Channel {
        id: number;
        is_banned: boolean;
    }
    interface StoppedLivestream {
        id: number;
        channel: Channel;
    }
    interface StopStreamBroadcastData {
        livestream: StoppedLivestream;
    }
    interface StopStreamBroadcast {
        event: 'App\\Events\\StopStreamBroadcast';
        data: string;
        channel: string;
    }
    interface SubscriptionEventData {
        chatroom_id: number;
        username: string;
        months: number;
    }
    interface SubscriptionEvent {
        event: 'App\\Events\\SubscriptionEvent';
        data: string;
        channel: string;
    }
    type RootResponse = ConnectionEstablished | SubscriptionSucceeded | ChatMessageEvent | ChatMessageReact | FollowersUpdate | ChatMessageDeleted | LuckyUsersWhoGotGiftSubscriptionsEvent | GiftsLeaderboardUpdated | StreamerIsLive | SubscriptionEvent | ChatMessageDeletedEvent | StopStreamBroadcast;
    interface CommentResponse extends BaseResponse {
        origin: any;
        anonymity: boolean;
    }
}
