import { BaseResponse } from "./BaseResponse";
export declare namespace NicoNama {
    interface Icon {
        urls: {
            [size: string]: string;
        };
    }
    interface User {
        description: string;
        hasPremiumOrStrongerRights: false;
        hasSuperPremiumOrStrongerRights: false;
        icons: Icon;
        nickname: string;
        userId: string;
    }
    interface Meta {
        status: number;
        hasNext: boolean;
        maxId: string;
        minId: string;
        errors: any[];
    }
    interface WatchContext {
        parameter: Parameter;
    }
    interface Parameter {
        nicorepo: string;
    }
    interface Actor {
        url: string;
        name: string;
        icon: string;
    }
    interface DaumObject {
        type: string;
        url: string;
        name: string;
        image: string;
    }
    interface Daum {
        id: string;
        updated: string;
        watchContext: WatchContext;
        actor: Actor;
        title: string;
        object: DaumObject;
    }
    interface UserEntryResponse {
        meta: Meta;
        data: Daum[];
        errors: any[];
    }
    interface UserDataResponse {
        data: User[];
        meta: {
            status: number;
        };
    }
    interface Chat {
        name?: string;
        anonymity?: number;
        content: string;
        date: number;
        date_usec: number;
        mail?: string;
        no: number;
        premium: number;
        thread: string;
        user_id: string;
        vpos: number;
    }
    interface Thread {
        last_res: number;
        resultcode: number;
        revision: number;
        server_time: number;
        thread: string;
        ticket: string;
    }
    interface MetaResponse {
        type: string;
        data: any;
    }
    interface RootResponse {
        chat?: Chat;
        thread?: Thread;
    }
    interface EmotionHistoryElement {
        emotionId: string;
        name: string;
        thumbnailUrl: string;
        seqNum: number;
        staminaSum: number;
    }
    interface EmotionData {
        contentType: string;
        contentId: string;
        liveCycle: string;
        isAvailable: boolean;
        isPublishable: boolean;
        hasReachedEmotionLimit: boolean;
        enabledByOwner: boolean;
        isOwner: boolean;
        user: User;
        staminaMaxFactor: number;
        token: string;
        emotionHistoryElements: EmotionHistoryElement[];
    }
    interface Reaction {
        key: string;
        src: string;
        value: number;
    }
    interface Emotion {
        id: string;
        name: string;
        description: string;
        thumbnailUrl: string;
        stamina: number;
    }
    interface EmotionGroup {
        id: number;
        name: string;
        emotions: Emotion[];
        isOwnerOnly: boolean;
    }
    interface EmotionGroupData {
        groups: EmotionGroup[];
    }
    interface EmotionGroupResponse {
        meta: {
            status: number;
        };
        data: EmotionGroupData;
    }
    interface EmotionResponse {
        meta: {
            status: number;
        };
        data: EmotionData;
    }
    interface CommentResponse extends BaseResponse {
        vpos: number;
        thread: string;
        dateUsec: number;
        mail: string;
        premium: number;
        anonymity: boolean;
        isSystem: boolean;
        command: string;
        commandPrefix: string;
        giftRank: string;
        price: number;
        no: number;
        commentVisible?: boolean;
        screenName: string;
        origin?: string;
    }
    interface Id {
        value: string;
    }
    interface AudienceLimitation {
        loginLimitation: string;
    }
    interface Features {
        enabledList: string[];
    }
    interface KonomiTags {
        itemsList: any[];
    }
    interface Program {
        title: string;
        description: string;
        provider: string;
        schedule: Schedule;
        additionalDescriptions: unknown;
    }
    interface Schedule {
        status: string;
        openTime: OpenTime;
        beginTime: BeginTime;
        scheduledEndTime: ScheduledEndTime;
        endTime: EndTime;
        vposBaseTime: VposBaseTime;
    }
    interface OpenTime {
        seconds: number;
        nanos: number;
    }
    interface BeginTime {
        seconds: number;
        nanos: number;
    }
    interface ScheduledEndTime {
        seconds: number;
        nanos: number;
    }
    interface EndTime {
        seconds: number;
        nanos: number;
    }
    interface VposBaseTime {
        seconds: number;
        nanos: number;
    }
    interface ProgramProvider {
        type: string;
        name: string;
        profileUrl: string;
        nicopediaArticleUrl: NicopediaArticleUrl;
        programProviderId: ProgramProviderId;
        icons: Icons;
        userLevel: UserLevel;
        isStandardAccount: IsStandardAccount;
        description: Description;
    }
    interface NicopediaArticleUrl {
        value: string;
    }
    interface ProgramProviderId {
        value: string;
    }
    interface Icons {
        uri150x150: string;
        uri50x50: string;
    }
    interface UserLevel {
        value: number;
    }
    interface IsStandardAccount {
        value: boolean;
    }
    interface Description {
        value: string;
    }
    interface SocialGroup {
        socialGroupId: string;
        type: string;
        name: string;
        description: string;
        thumbnail: string;
        thumbnailSmall: string;
        isSafeThumbnail: IsSafeThumbnail;
        level: Level;
        isFollowed: boolean;
        isJoined: boolean;
        isDeleted: IsDeleted;
    }
    interface IsSafeThumbnail {
        value: boolean;
    }
    interface Level {
        value: number;
    }
    interface IsDeleted {
        value: boolean;
    }
    interface Statistics {
        viewers: Viewers;
        comments: Comments;
        timeshiftReservations?: TimeshiftReservations;
    }
    interface Viewers {
        value: number;
    }
    interface Comments {
        value: number;
    }
    interface TimeshiftReservations {
        value: number;
    }
    interface Taxonomy {
        tags: Tags;
        categories: Categories;
    }
    interface Tags {
        itemsList: ItemsList[];
        ownerLocked: boolean;
    }
    interface ItemsList {
        text: string;
        locked: boolean;
        reserved: boolean;
        nicopediaArticleUrl?: NicopediaArticleUrl2;
    }
    interface NicopediaArticleUrl2 {
        value: string;
    }
    interface MainList {
        text: string;
        nicopediaArticleUrl: NicopediaArticleUrl3;
    }
    interface NicopediaArticleUrl3 {
        value: string;
    }
    interface SubList {
        text: string;
        nicopediaArticleUrl: NicopediaArticleUrl4;
    }
    interface NicopediaArticleUrl4 {
        value: string;
    }
    interface Categories {
        mainList: MainList[];
        subList: SubList[];
    }
    interface Thumbnail {
        screenshot?: Screenshot;
    }
    interface Screenshot {
        large: string;
        middle: string;
        small: string;
        micro: string;
    }
    interface TimeshiftSetting {
        watchLimit: string;
        requirement: string;
        status: string;
        endTime: EndTime2;
        reservationDeadline: ReservationDeadline;
    }
    interface EndTime2 {
        seconds: number;
        nanos: number;
    }
    interface ReservationDeadline {
        seconds: number;
        nanos: number;
    }
    interface ProgramsList {
        id: Id;
        publicStatus: number;
        audienceLimitation: AudienceLimitation;
        features: Features;
        konomiTags: KonomiTags;
        program: Program;
        programProvider: ProgramProvider;
        socialGroup: SocialGroup;
        statistics: Statistics;
        taxonomy: Taxonomy;
        thumbnail: Thumbnail;
        timeshiftSetting?: TimeshiftSetting;
    }
    interface BroadcastHistoryData {
        programsList: ProgramsList[];
        hasNext: boolean;
        totalCount: number;
    }
    interface UserBroadcastHistory {
        meta: Meta;
        data: BroadcastHistoryData;
    }
}
