import Store from 'electron-store';
import { ConnectedData, SendType } from './Api';
import { Comment } from './Comment';
import { Service } from './Service';
import { UserNameData } from './UserData';
import { SpeechConfig } from './Config';
export type PluginFilterEvent = 'filter.comment' | 'filter.speech';
export interface PluginRequest {
    url: string;
    method: 'GET' | 'POST' | 'PUT' | 'DELETE';
    params: {
        [key: string]: string;
    };
    body?: any;
}
export interface PluginResponse {
    code: number;
    response: string;
}
export interface PluginAPI {
    dir: string;
    filepath: string;
    store: Store;
}
export interface PluginData {
    plugin: OnePlugin;
    api: PluginAPI;
    activated: boolean;
}
export interface OnePlugin {
    uid: string;
    name: string;
    version: string;
    permissions: (SendType | PluginFilterEvent)[];
    author?: string;
    url?: string;
    defaultState: Record<string, any>;
    init?(api: PluginAPI, initialData: Partial<ConnectedData>): void;
    subscribe?(type: SendType, ...args: any[]): void;
    request?(req: PluginRequest): Promise<PluginResponse>;
    filterComment?(comment: Comment, service: Service, userData: UserNameData | null): Promise<Comment | false>;
    filterSpeech?(text: string, service: Service, userData: UserNameData | null, config: SpeechConfig): Promise<string | false>;
    destroy?(): void;
    [key: string]: any;
}
export type PluginInternal = (Pick<OnePlugin, 'uid' | 'name' | 'version' | 'url' | 'author' | 'permissions'> & {
    activated: boolean;
});
export type PluginList = PluginInternal[];
