import { BaseResponse } from "./BaseResponse";
export declare namespace Streamlabs {
    interface To {
        name: string;
    }
    interface DonationPayload {
        name: string;
        isTest: boolean;
        formatted_amount: string;
        amount: number;
        message: string;
        currency: string;
        to: To;
        from: string;
        from_user_id: number;
        _id: string;
        priority: number;
    }
    interface Donation {
        type: 'donation';
        priority: number;
        _id: string;
        from: string;
        fromId: string;
        to: string;
        message: string;
        amount: string;
        currency: string;
        payload: DonationPayload;
        gif?: any;
        mask_name?: any;
        mask_rarity?: any;
        pro?: any;
        pro_extras?: any;
        senderId: number;
        emotes?: any;
        wishListItem?: any;
        name: string;
        isTest: boolean;
        repeat: boolean;
        alert_status: number;
        createdAt: string;
        createdAtTimestamp: number;
        source: string;
        donation_id: string;
        legacyHash: string;
        hash: string;
        read: boolean;
        donationCurrency: string;
        wotcCode?: any;
        attachments: any[];
        clippingEnabled: boolean;
        skipAlert: boolean;
        recurring_donation?: any;
        charityName?: any;
        rawAmount: number;
    }
    interface FollowPayload {
        name: string;
        isTest: boolean;
        _id: string;
        priority: number;
    }
    interface SuperchatPayload2 {
        currency: string;
    }
    interface SuperchatPayload {
        name: string;
        isTest: boolean;
        amount: number;
        displayString: string;
        comment: string;
        id: number;
        channelId: string;
        currency: string;
        payload: SuperchatPayload2;
        _id: string;
        priority: number;
    }
    interface SubscriptionPayload {
        name: string;
        isTest: boolean;
        months: number;
        message: string;
        emotes?: any;
        sub_plan: string;
        _id: string;
        priority: number;
    }
    interface Follow {
        type: 'follor';
        priority: number;
        _id: string;
        from: string;
        to: string;
        message: string;
        payload: FollowPayload;
        name: string;
        repeat: boolean;
        isTest: boolean;
        createdAt: string;
        createdAtTimestamp: number;
        platform: string;
        hash: string;
        read: boolean;
    }
    interface Superchat {
        type: 'superchat';
        priority: number;
        _id: string;
        from: string;
        amount: number;
        message: string;
        payload: SuperchatPayload;
        displayString: string;
        name: string;
        repeat: boolean;
        isTest: boolean;
        platform: string;
        createdAt: string;
        createdAtTimestamp: number;
        comment: string;
        hash: string;
        read: boolean;
        currency: string;
        channelId: string;
    }
    interface Merch {
        type: undefined;
        priority: number;
        _id: string;
        from: string;
        to: To;
        message: string;
        payload: any;
        imageHref: string;
        duration?: any;
        isTest: boolean;
        repeat: boolean;
        product: string;
        condition: string;
        createdAt: string;
        createdAtTimestamp: number;
    }
    interface Subscription {
        type: 'subscription';
        priority: number;
        _id: string;
        from: string;
        from_display_name?: any;
        emotes?: any;
        months: number;
        streak_months?: any;
        message: string;
        payload: SubscriptionPayload;
        name: string;
        display_name?: any;
        subPlan: string;
        sub_plan: string;
        subscriber_twitch_id?: any;
        gifter: string;
        gifter_display_name?: any;
        count: number;
        repeat: boolean;
        isTest: boolean;
        createdAt: string;
        createdAtTimestamp: number;
        platform: string;
        planName: string;
        sub_type?: any;
        hash: string;
        read: boolean;
        amount?: any;
        membershipLevel?: any;
        membershipLevelName?: any;
        membershipGift?: any;
        membershipGiftMessageId?: any;
        massSubGiftChildAlerts: any[];
        isSubgiftExpanded: boolean;
        benefit_end_month?: any;
    }
    interface CloudbotStore {
        name: string;
        isTest: boolean;
        message: string;
        to: To;
        from: string;
        product: string;
        imageHref: string;
        _id: string;
        priority: number;
    }
    interface PrimeGift {
        name: string;
        isTest: boolean;
        from: string;
        to: string;
        gift_type: string;
        _id: string;
        priority: number;
    }
    interface EventResponse {
        type: 'event';
        for: string;
        method: string;
        arguments: any[];
    }
    interface PrimeGiftResponse extends EventResponse {
        method: 'onPrime_sub_gift';
        arguments: [PrimeGift[], string];
    }
    interface CloudbotStoreResponse extends EventResponse {
        method: 'onLoyalty_store_redemption';
        arguments: [CloudbotStore[], string];
    }
    interface MerchResponse extends EventResponse {
        method: 'onMerch';
        arguments: [Merch, string];
    }
    interface SuperchatResponse extends EventResponse {
        method: 'onSuperchat';
        arguments: [Superchat[], string];
    }
    interface SubscriptionResponse extends EventResponse {
        method: 'onSubscription';
        arguments: [Subscription[], string];
    }
    interface FollowResponse extends EventResponse {
        method: 'onFollow';
        arguments: [Follow[], string];
    }
    interface DonationResponse extends EventResponse {
        method: 'onDonation';
        arguments: [Donation, string];
    }
    interface ConnectedResponse {
        type: 'connected';
        id: string;
    }
    type RootResponse = ConnectedResponse | DonationResponse | FollowResponse | SubscriptionResponse | SuperchatResponse | MerchResponse | CloudbotStoreResponse | PrimeGiftResponse;
    interface CommentResponse extends BaseResponse {
        price?: number;
        unit?: string;
    }
    interface Settings {
        donation_variations: any[];
        merch_variations: any[];
        pledge_variations: any[];
        eldonation_variations: any[];
        tiltifydonation_variations: any[];
        gamewispsubscription_variations: any[];
        treat_variations: any[];
        donordrivedonation_variations: any[];
        justgivingdonation_variations: any[];
        loyalty_store_redemption_variations: any[];
        sponsored_campaign_variations: any[];
        prime_sub_gift_variations: any[];
        streamlabscharitydonation_variations: any[];
        background_color: string;
        alert_delay: number;
        moderation_delay: number;
        censor_streamer_recent_events: boolean;
        unlimited_media_moderation_delay: boolean;
        layout: string;
        display_mtg_codes: boolean;
        automatically_reset_session: boolean;
        donation_layout: string;
        donation_enabled: boolean;
        donation_tts_enabled: string;
        donation_tts_include_message_template: boolean;
        donation_tts_language: string;
        donation_tts_security: number;
        donation_tts_repetition_block_length: number;
        donation_tts_volume: number;
        donation_message_template: string;
        donation_text_animation: string;
        donation_image_href: string;
        donation_sound_href: string;
        donation_sound_volume: number;
        donation_font: string;
        donation_font_size: string;
        donation_font_weight: string;
        donation_font_color: string;
        donation_font_color2: string;
        donation_alert_duration: number;
        donation_text_delay: number;
        donation_alert_min_amount: number;
        recent_events_donation_min_amount: number;
        donation_alert_message_min_amount: number;
        donation_tts_min_amount: number;
        donation_moderation: boolean;
        show_donation_message: boolean;
        donation_show_animation: string;
        donation_hide_animation: string;
        donation_custom_html_enabled: boolean;
        donation_custom_html: string;
        donation_custom_js: string;
        donation_custom_css: string;
        donation_custom_json?: any;
        donation_message_font_size: string;
        donation_message_font: string;
        donation_message_font_weight: string;
        donation_message_font_color: string;
        donation_message_allow_emotes: boolean;
        donation_gif_enabled: boolean;
        donation_gifs_min_amount_to_share: number;
        donation_gfycat_library_enabled: boolean;
        donation_gif_library_enabled: boolean;
        donation_gif_animation: string;
        donation_max_gif_duration?: any;
        donation_gif_library_defaults: string;
        donation_clipping_enabled: boolean;
        pledge_layout: string;
        pledge_enabled: boolean;
        pledge_message_template: string;
        pledge_text_animation: string;
        pledge_image_href: string;
        pledge_sound_href: string;
        pledge_sound_volume: number;
        pledge_font: string;
        pledge_font_size: string;
        pledge_font_weight: string;
        pledge_font_color: string;
        pledge_font_color2: string;
        pledge_alert_duration: number;
        pledge_text_delay: number;
        pledge_show_animation: string;
        pledge_hide_animation: string;
        pledge_custom_html_enabled: boolean;
        pledge_custom_html: string;
        pledge_custom_js: string;
        pledge_custom_css: string;
        pledge_custom_json?: any;
        eldonation_layout: string;
        eldonation_enabled: boolean;
        eldonation_message_template: string;
        eldonation_text_animation: string;
        eldonation_image_href: string;
        eldonation_sound_href: string;
        eldonation_sound_volume: number;
        eldonation_font: string;
        eldonation_font_size: string;
        eldonation_font_weight: string;
        eldonation_font_color: string;
        eldonation_font_color2: string;
        eldonation_alert_duration: number;
        eldonation_text_delay: number;
        eldonation_show_animation: string;
        eldonation_hide_animation: string;
        eldonation_custom_html_enabled: boolean;
        eldonation_custom_html: string;
        eldonation_custom_js: string;
        eldonation_custom_css: string;
        eldonation_custom_json?: any;
        show_eldonation_message: boolean;
        eldonation_message_font_size: string;
        eldonation_message_font: string;
        eldonation_message_font_weight: string;
        eldonation_message_font_color: string;
        eldonation_alert_message_min_amount: number;
        tiltifydonation_layout: string;
        tiltifydonation_enabled: boolean;
        tiltifydonation_message_template: string;
        tiltifydonation_text_animation: string;
        tiltifydonation_image_href: string;
        tiltifydonation_sound_href: string;
        tiltifydonation_sound_volume: number;
        tiltifydonation_font: string;
        tiltifydonation_font_size: string;
        tiltifydonation_font_weight: string;
        tiltifydonation_font_color: string;
        tiltifydonation_font_color2: string;
        tiltifydonation_alert_duration: number;
        tiltifydonation_text_delay: number;
        tiltifydonation_show_animation: string;
        tiltifydonation_hide_animation: string;
        tiltifydonation_custom_html_enabled: boolean;
        tiltifydonation_custom_html: string;
        tiltifydonation_custom_js: string;
        tiltifydonation_custom_css: string;
        tiltifydonation_custom_json?: any;
        show_tiltifydonation_message: boolean;
        tiltifydonation_message_font_size: string;
        tiltifydonation_message_font: string;
        tiltifydonation_message_font_weight: string;
        tiltifydonation_message_font_color: string;
        tiltifydonation_alert_message_min_amount: number;
        recent_events_tiltifydonation_min_amount: number;
        gamewispsubscription_layout: string;
        gamewispsubscription_enabled: boolean;
        gamewispsubscription_message_template: string;
        gamewispsubscription_resub_message_template: string;
        gamewispsubscription_tier_upgrade_message_template: string;
        gamewispsubscription_text_animation: string;
        gamewispsubscription_image_href: string;
        gamewispsubscription_sound_href: string;
        gamewispsubscription_sound_volume: number;
        gamewispsubscription_font: string;
        gamewispsubscription_font_size: string;
        gamewispsubscription_font_weight: string;
        gamewispsubscription_font_color: string;
        gamewispsubscription_font_color2: string;
        gamewispsubscription_alert_duration: number;
        gamewispsubscription_text_delay: number;
        gamewispsubscription_show_animation: string;
        gamewispsubscription_hide_animation: string;
        gamewispsubscription_custom_html_enabled: boolean;
        gamewispsubscription_custom_html: string;
        gamewispsubscription_custom_js: string;
        gamewispsubscription_custom_css: string;
        gamewispsubscription_custom_json?: any;
        treat_layout: string;
        treat_enabled: boolean;
        treat_message_template: string;
        treat_text_animation: string;
        treat_image_href: string;
        treat_sound_href: string;
        treat_sound_volume: number;
        treat_font: string;
        treat_font_size: string;
        treat_font_weight: string;
        treat_font_color: string;
        treat_font_color2: string;
        treat_alert_duration: number;
        treat_text_delay: number;
        treat_show_animation: string;
        treat_hide_animation: string;
        treat_custom_html_enabled: boolean;
        treat_custom_html: string;
        treat_custom_js: string;
        treat_custom_css: string;
        treat_custom_json?: any;
        show_treat_message: boolean;
        treat_message_font_size: string;
        treat_message_font: string;
        treat_message_font_weight: string;
        treat_message_font_color: string;
        merch_layout: string;
        merch_enabled: boolean;
        merch_message_template: string;
        merch_text_animation: string;
        merch_image_href: string;
        merch_sound_href: string;
        merch_sound_volume: number;
        merch_font: string;
        merch_font_size: string;
        merch_font_weight: string;
        merch_font_color: string;
        merch_font_color2: string;
        merch_alert_duration: number;
        merch_text_delay: number;
        merch_moderation: boolean;
        show_merch_message: boolean;
        merch_show_animation: string;
        merch_hide_animation: string;
        merch_custom_html_enabled: boolean;
        merch_custom_html: string;
        merch_custom_js: string;
        merch_custom_css: string;
        merch_custom_json?: any;
        merch_message_font_size: string;
        merch_message_font: string;
        merch_message_font_weight: string;
        merch_message_font_color: string;
        merch_message_allow_emotes: boolean;
        merch_use_custom_image: boolean;
        donordrivedonation_layout: string;
        donordrivedonation_enabled: boolean;
        donordrivedonation_message_template: string;
        donordrivedonation_text_animation: string;
        donordrivedonation_image_href: string;
        donordrivedonation_sound_href: string;
        donordrivedonation_sound_volume: number;
        donordrivedonation_font: string;
        donordrivedonation_font_size: string;
        donordrivedonation_font_weight: string;
        donordrivedonation_font_color: string;
        donordrivedonation_font_color2: string;
        donordrivedonation_alert_duration: number;
        donordrivedonation_text_delay: number;
        donordrivedonation_show_animation: string;
        donordrivedonation_hide_animation: string;
        donordrivedonation_custom_html_enabled: boolean;
        donordrivedonation_custom_html: string;
        donordrivedonation_custom_js: string;
        donordrivedonation_custom_css: string;
        donordrivedonation_custom_json?: any;
        show_donordrivedonation_message: boolean;
        donordrivedonation_message_font_size: string;
        donordrivedonation_message_font: string;
        donordrivedonation_message_font_weight: string;
        donordrivedonation_message_font_color: string;
        donordrivedonation_alert_message_min_amount: number;
        justgivingdonation_layout: string;
        justgivingdonation_enabled: boolean;
        justgivingdonation_message_template: string;
        justgivingdonation_text_animation: string;
        justgivingdonation_image_href: string;
        justgivingdonation_sound_href: string;
        justgivingdonation_sound_volume: number;
        justgivingdonation_font: string;
        justgivingdonation_font_size: string;
        justgivingdonation_font_weight: string;
        justgivingdonation_font_color: string;
        justgivingdonation_font_color2: string;
        justgivingdonation_alert_duration: number;
        justgivingdonation_text_delay: number;
        justgivingdonation_show_animation: string;
        justgivingdonation_hide_animation: string;
        justgivingdonation_custom_html_enabled: boolean;
        justgivingdonation_custom_html: string;
        justgivingdonation_custom_js: string;
        justgivingdonation_custom_css: string;
        justgivingdonation_custom_json?: any;
        show_justgivingdonation_message: boolean;
        justgivingdonation_message_font_size: string;
        justgivingdonation_message_font: string;
        justgivingdonation_message_font_weight: string;
        justgivingdonation_message_font_color: string;
        justgivingdonation_alert_message_min_amount: number;
        loyalty_store_redemption_layout: string;
        loyalty_store_redemption_enabled: boolean;
        loyalty_store_redemption_message_template: string;
        loyalty_store_redemption_text_animation: string;
        loyalty_store_redemption_image_href: string;
        loyalty_store_redemption_sound_href: string;
        loyalty_store_redemption_sound_volume: number;
        loyalty_store_redemption_font: string;
        loyalty_store_redemption_font_size: string;
        loyalty_store_redemption_font_weight: string;
        loyalty_store_redemption_font_color: string;
        loyalty_store_redemption_font_color2: string;
        loyalty_store_redemption_alert_duration: number;
        loyalty_store_redemption_text_delay: number;
        loyalty_store_redemption_moderation: boolean;
        show_loyalty_store_redemption_message: boolean;
        loyalty_store_redemption_show_animation: string;
        loyalty_store_redemption_hide_animation: string;
        loyalty_store_redemption_custom_html_enabled: boolean;
        loyalty_store_redemption_custom_html: string;
        loyalty_store_redemption_custom_js: string;
        loyalty_store_redemption_custom_css: string;
        loyalty_store_redemption_custom_json?: any;
        loyalty_store_redemption_message_font_size: string;
        loyalty_store_redemption_message_font: string;
        loyalty_store_redemption_message_font_weight: string;
        loyalty_store_redemption_message_font_color: string;
        loyalty_store_redemption_message_allow_emotes: boolean;
        loyalty_store_redemption_use_custom_image: boolean;
        prime_sub_gift_layout: string;
        prime_sub_gift_enabled: boolean;
        prime_sub_gift_message_template: string;
        prime_sub_gift_text_animation: string;
        prime_sub_gift_image_href: string;
        prime_sub_gift_sound_href: string;
        prime_sub_gift_sound_volume: number;
        prime_sub_gift_font: string;
        prime_sub_gift_font_size: string;
        prime_sub_gift_font_weight: string;
        prime_sub_gift_font_color: string;
        prime_sub_gift_font_color2: string;
        prime_sub_gift_alert_duration: number;
        prime_sub_gift_text_delay: number;
        prime_sub_gift_show_animation: string;
        prime_sub_gift_hide_animation: string;
        prime_sub_gift_custom_html_enabled: boolean;
        prime_sub_gift_custom_html: string;
        prime_sub_gift_custom_js: string;
        prime_sub_gift_custom_css: string;
        prime_sub_gift_custom_json?: any;
        prime_sub_gift_enable_confetti: boolean;
        sponsored_campaign_layout: string;
        sponsored_campaign_enabled: boolean;
        sponsored_campaign_message_template: string;
        sponsored_campaign_text_animation: string;
        sponsored_campaign_image_href: string;
        sponsored_campaign_sound_href: string;
        sponsored_campaign_sound_volume: number;
        sponsored_campaign_font: string;
        sponsored_campaign_font_size: string;
        sponsored_campaign_font_weight: string;
        sponsored_campaign_font_color: string;
        sponsored_campaign_font_color2: string;
        sponsored_campaign_alert_duration: number;
        sponsored_campaign_text_delay: number;
        sponsored_campaign_moderation: boolean;
        sponsored_campaign_show_animation: string;
        sponsored_campaign_hide_animation: string;
        sponsored_campaign_custom_html_enabled: boolean;
        sponsored_campaign_custom_html: string;
        sponsored_campaign_custom_js: string;
        sponsored_campaign_custom_css: string;
        sponsored_campaign_custom_json?: any;
        interrupt_mode: boolean;
        interrupt_mode_delay: number;
        alerts_master_sound_volume: number;
        tts_master_sound_volume: number;
        streamlabscharitydonation_layout: string;
        streamlabscharitydonation_enabled: boolean;
        streamlabscharitydonation_message_template: string;
        streamlabscharitydonation_text_animation: string;
        streamlabscharitydonation_image_href: string;
        streamlabscharitydonation_sound_href: string;
        streamlabscharitydonation_sound_volume: number;
        streamlabscharitydonation_font: string;
        streamlabscharitydonation_font_size: string;
        streamlabscharitydonation_font_weight: string;
        streamlabscharitydonation_font_color: string;
        streamlabscharitydonation_font_color2: string;
        streamlabscharitydonation_alert_duration: number;
        streamlabscharitydonation_text_delay: number;
        auto_streamlabscharitydonation_enabled: boolean;
        streamlabscharitydonation_viewer_minimum: number;
        streamlabscharitydonation_show_animation: string;
        streamlabscharitydonation_hide_animation: string;
        streamlabscharitydonation_custom_html_enabled: boolean;
        streamlabscharitydonation_custom_html: string;
        streamlabscharitydonation_custom_js: string;
        streamlabscharitydonation_custom_css: string;
        streamlabscharitydonation_custom_json?: any;
        show_streamlabscharitydonation_message: boolean;
        streamlabscharitydonation_message_font_size: string;
        streamlabscharitydonation_message_font: string;
        streamlabscharitydonation_message_font_weight: string;
        streamlabscharitydonation_message_font_color: string;
        streamlabscharitydonation_alert_message_min_amount: number;
        streamlabscharitydonation_gif_enabled: boolean;
        streamlabscharitydonation_gifs_min_amount_to_share: number;
        streamlabscharitydonation_gfycat_library_enabled: boolean;
        streamlabscharitydonation_gif_library_enabled: boolean;
        streamlabscharitydonation_gif_animation: string;
        streamlabscharitydonation_max_gif_duration: number;
        streamlabscharitydonation_gif_library_defaults: string;
        streamlabscharitydonation_tts_enabled: boolean;
        streamlabscharitydonation_tts_include_message_template: boolean;
        streamlabscharitydonation_tts_language: string;
        streamlabscharitydonation_tts_security: number;
        streamlabscharitydonation_tts_repetition_block_length: number;
        streamlabscharitydonation_tts_volume: number;
        streamlabscharitydonation_tts_min_amount: number;
        streamlabscharitydonation_alert_min_amount: number;
        recent_events_streamlabscharitydonation_min_amount: number;
        mobile_custom_theme_id: number;
        follow_variations: any[];
        sub_variations: any[];
        host_variations: any[];
        bit_variations: any[];
        raid_variations: any[];
        follow_layout: string;
        follow_enabled: boolean;
        follow_message_template: string;
        follow_text_animation: string;
        follow_image_href: string;
        follow_sound_href: string;
        follow_sound_volume: number;
        follow_font: string;
        follow_font_size: string;
        follow_font_weight: string;
        follow_font_color: string;
        follow_font_color2: string;
        follow_alert_duration: number;
        follow_text_delay: number;
        follow_show_animation: string;
        follow_hide_animation: string;
        follow_custom_html_enabled: boolean;
        follow_custom_html: string;
        follow_custom_js: string;
        follow_custom_css: string;
        follow_custom_json?: any;
        sub_layout: string;
        sub_enabled: boolean;
        sub_message_template: string;
        sub_text_animation: string;
        sub_image_href: string;
        sub_sound_href: string;
        sub_sound_volume: number;
        sub_font: string;
        sub_font_size: string;
        sub_font_weight: string;
        sub_font_color: string;
        sub_font_color2: string;
        sub_alert_duration: number;
        sub_text_delay: number;
        prime_sub_enabled: boolean;
        sub_show_animation: string;
        sub_hide_animation: string;
        sub_custom_html_enabled: boolean;
        sub_custom_html: string;
        sub_custom_js: string;
        sub_custom_css: string;
        sub_custom_json?: any;
        host_layout: string;
        host_enabled: boolean;
        host_message_template: string;
        host_text_animation: string;
        host_image_href: string;
        host_sound_href: string;
        host_sound_volume: number;
        host_font: string;
        host_font_size: string;
        host_font_weight: string;
        host_font_color: string;
        host_font_color2: string;
        host_alert_duration: number;
        host_text_delay: number;
        auto_host_enabled: boolean;
        host_viewer_minimum: number;
        recent_events_host_min_viewer_count: number;
        host_show_animation: string;
        host_hide_animation: string;
        host_custom_html_enabled: boolean;
        host_custom_html: string;
        host_custom_js: string;
        host_custom_css: string;
        host_custom_json?: any;
        resub_message_font_size: string;
        resub_message_font: string;
        resub_message_font_weight: string;
        resub_message_font_color: string;
        resub_message_allow_emotes: boolean;
        show_resub_message: boolean;
        resub_tts_enabled: boolean;
        resub_tts_include_message_template: boolean;
        resub_tts_language: string;
        resub_tts_security: number;
        resub_tts_repetition_block_length: number;
        resub_tts_volume: number;
        bits_layout: string;
        bits_enabled: boolean;
        bits_tts_enabled: boolean;
        bits_tts_include_message_template: boolean;
        bits_tts_language: string;
        bits_tts_security: number;
        bits_tts_repetition_block_length: number;
        bits_tts_volume: number;
        bits_message_template: string;
        bits_text_animation: string;
        bits_image_href: string;
        bits_sound_href: string;
        bits_sound_volume: number;
        bits_font: string;
        bits_font_size: string;
        bits_font_weight: string;
        bits_font_color: string;
        bits_font_color2: string;
        bits_alert_duration: number;
        bits_text_delay: number;
        bits_alert_min_amount: number;
        bits_alert_message_min_amount: number;
        bits_tts_min_amount: number;
        show_bits_message: boolean;
        bits_show_animation: string;
        bits_hide_animation: string;
        bits_message_font_size: string;
        bits_message_font: string;
        bits_message_font_weight: string;
        bits_message_font_color: string;
        bits_message_allow_emotes: boolean;
        bits_custom_html_enabled: boolean;
        bits_custom_html: string;
        bits_custom_js: string;
        bits_custom_css: string;
        bits_custom_json?: any;
        recent_events_bits_min_amount: number;
        recent_events_raid_min_viewer_count: number;
        raid_layout: string;
        raid_enabled: boolean;
        raid_message_template: string;
        raid_text_animation: string;
        raid_image_href: string;
        raid_sound_href: string;
        raid_sound_volume: number;
        raid_font: string;
        raid_font_size: string;
        raid_font_weight: string;
        raid_font_color: string;
        raid_font_color2: string;
        raid_alert_duration: number;
        raid_text_delay: number;
        raid_raider_minimum: number;
        raid_show_animation: string;
        raid_hide_animation: string;
        raid_custom_html_enabled: boolean;
        raid_custom_html: string;
        raid_custom_js: string;
        raid_custom_css: string;
        raid_custom_json?: any;
        subscriber_variations: any[];
        sponsor_variations: any[];
        fanfunding_variations: any[];
        subscriber_layout: string;
        subscriber_enabled: boolean;
        subscriber_message_template: string;
        subscriber_text_animation: string;
        subscriber_image_href: string;
        subscriber_sound_href: string;
        subscriber_sound_volume: number;
        subscriber_font: string;
        subscriber_font_size: string;
        subscriber_font_weight: string;
        subscriber_font_color: string;
        subscriber_font_color2: string;
        subscriber_alert_duration: number;
        subscriber_text_delay: number;
        subscriber_show_animation: string;
        subscriber_hide_animation: string;
        subscriber_custom_html_enabled: boolean;
        subscriber_custom_html: string;
        subscriber_custom_js: string;
        subscriber_custom_css: string;
        subscriber_custom_json?: any;
        member_gift_message_template: string;
        member_gift_message_level_template: string;
        member_gif_image_href: string;
        member_gift_sound_href: string;
        sponsor_layout: string;
        sponsor_enabled: boolean;
        sponsor_message_template: string;
        sponsor_text_animation: string;
        sponsor_image_href: string;
        sponsor_sound_href: string;
        sponsor_sound_volume: number;
        sponsor_font: string;
        sponsor_font_size: string;
        sponsor_font_weight: string;
        sponsor_font_color: string;
        sponsor_font_color2: string;
        sponsor_alert_duration: number;
        sponsor_text_delay: number;
        sponsor_show_animation: string;
        sponsor_hide_animation: string;
        sponsor_custom_html_enabled: boolean;
        sponsor_custom_html: string;
        sponsor_custom_js: string;
        sponsor_custom_css: string;
        sponsor_custom_json?: any;
        fanfunding_layout: string;
        fanfunding_enabled: boolean;
        fanfunding_tts_enabled: boolean;
        fanfunding_tts_include_message_template: boolean;
        fanfunding_tts_language: string;
        fanfunding_tts_security: number;
        fanfunding_tts_repetition_block_length: number;
        fanfunding_tts_volume: number;
        fanfunding_message_template: string;
        fanfunding_text_animation: string;
        fanfunding_image_href: string;
        fanfunding_sound_href: string;
        fanfunding_sound_volume: number;
        fanfunding_font: string;
        fanfunding_font_size: string;
        fanfunding_font_weight: string;
        fanfunding_font_color: string;
        fanfunding_font_color2: string;
        fanfunding_alert_duration: number;
        fanfunding_text_delay: number;
        fanfunding_alert_min_amount: number;
        fanfunding_alert_message_min_amount: number;
        fanfunding_tts_min_amount: number;
        fanfunding_custom_html_enabled: boolean;
        fanfunding_custom_html: string;
        fanfunding_custom_js: string;
        fanfunding_custom_css: string;
        fanfunding_custom_json?: any;
        show_fanfunding_message: boolean;
        fanfunding_show_animation: string;
        fanfunding_hide_animation: string;
        fanfunding_message_font_size: string;
        fanfunding_message_font: string;
        fanfunding_message_font_weight: string;
        fanfunding_message_font_color: string;
        recent_events_fanfunding_min_amount: number;
        facemaskdonation_layout: string;
        facemaskdonation_enabled: boolean;
        facemaskdonation_message_template: string;
        facemaskdonation_text_animation: string;
        facemaskdonation_image_href?: any;
        facemaskdonation_sound_href: string;
        facemaskdonation_sound_volume: number;
        facemaskdonation_font: string;
        facemaskdonation_font_size: string;
        facemaskdonation_font_weight: string;
        facemaskdonation_font_color: string;
        facemaskdonation_font_color2: string;
        facemaskdonation_alert_duration: number;
        facemaskdonation_text_delay: number;
        facemaskdonation_show_animation: string;
        facemaskdonation_hide_animation: string;
        facemaskdonation_custom_html_enabled: boolean;
        facemaskdonation_custom_html: string;
        facemaskdonation_custom_js: string;
        facemaskdonation_custom_css: string;
        facemaskdonation_custom_json?: any;
        show_facemaskdonation_message: boolean;
        facemaskdonation_message_font_size: string;
        facemaskdonation_message_font: string;
        facemaskdonation_message_font_weight: string;
        facemaskdonation_message_font_color: string;
        facemaskdonation_alert_message_min_amount: number;
        media_sharing_settings: any;
        mobile?: any;
        studio?: any;
        whitelist: string[];
    }
    interface Config {
        settings: Settings;
    }
}
