import { BaseResponse } from "./BaseResponse";
export declare namespace Tiktok {
    interface Gift {
        gift_id: number;
        repeat_count: number;
        repeat_end: number;
        gift_type: number;
    }
    interface Badge {
        type: string;
        name: string;
        displayType?: number;
        url?: string;
    }
    interface RootRoomInfo {
        title: string;
        owner_user_id: number;
        create_time: number;
    }
    interface RootRoomResponse {
        viewerCount: number;
    }
    interface RoomData {
        create_time: number;
        id_str: string;
        live_id: number;
        title: string;
        stream_status: number;
        owner: {
            display_id: string;
            nickname: string;
            bio_description: string;
        };
    }
    interface AccountData {
        user_id: number;
        user_id_str: string;
        odin_user_type: number;
        sec_user_id: string;
        screen_name: string;
        avatar_url: string;
        description: string;
        mobile: string;
        email: string;
        username: string;
        has_password: number;
        create_time: number;
        connects: Connect[];
        session_key: string;
        country_code: number;
        app_id: number;
    }
    interface Connect {
        screen_name: string;
        platform: string;
        profile_image_url: string;
        sec_platform_uid: string;
        create_time: number;
    }
    interface UserData {
        user_id: number;
        user_id_str: string;
        odin_user_type: number;
        sec_user_id: string;
        screen_name: string;
        avatar_url: string;
        description: string;
        mobile: string;
        email: string;
        username: string;
        has_password: number;
        create_time: number;
        connects: Connect[];
        session_key: string;
        country_code: number;
        app_id: number;
        is_employee: boolean;
        external_employee_platform: string;
    }
    interface Extra {
        now: number;
    }
    interface UserResponse {
        data: UserData;
        message: string;
    }
    interface AccountResponse {
        message: string;
        data: AccountData;
    }
    interface RoomResponse {
        data: RoomData;
        extra: any;
        status_code: number;
    }
    interface RootCommentResponse {
        secUid: string;
        comment: string;
        userId: string;
        uniqueId: string;
        nickname: string;
        profilePictureUrl: string;
        followRole: number;
        userBadges: Badge[];
        isModerator: boolean;
        isNewGifter: boolean;
        isSubscriber: boolean;
        topGifterRank?: any;
    }
    interface ProfilePicture {
        urls: string[];
    }
    interface FollowInfo {
        followingCount: number;
        followerCount: number;
        followStatus: number;
        pushStatus: number;
    }
    interface ImageBadgeData {
        displayType: number;
        image: {
            url: string;
        };
    }
    interface BadgeData {
        type: string;
        name: string;
    }
    interface UserBadge {
        badgeSceneType: number;
        badges?: BadgeData[];
        imageBadges?: ImageBadgeData[];
    }
    interface User {
        userId: Long;
        badges: UserBadge[];
        nickname: string;
        profilePicture: ProfilePicture;
        followInfo: FollowInfo;
        uniqueId: string;
        secUid: string;
        bioDescription?: string;
        createTime?: string;
    }
    interface EventDetails {
        displayType: string;
        label: string;
    }
    interface Long {
        high: number;
        low: number;
        unsigned: boolean;
        toString(): string;
        toNumber(): number;
    }
    interface Event {
        msgId: Long;
        createTime: Long;
        eventDetails?: EventDetails;
    }
    interface WebcastMemberMessageData {
        event: Event;
        user: User;
        actionId: number;
    }
    interface Data {
        event: Event;
        user: User;
        actionId: number;
        comment?: string;
    }
    interface TopViewer {
        coinCount: string;
        user: User;
    }
    interface WebcastRoomUserSeqMessageData {
        topViewers: TopViewer[];
        viewerCount: number;
    }
    interface WebcastLikeMessageData {
        event: Event;
        likeCount: number;
        totalLikeCount: number;
        user: User;
    }
    interface WebcastChatMessageData {
        event: Event;
        user: User;
        comment: string;
    }
    interface WebcastSocialMessageData {
        event: Event;
        user: User;
    }
    interface GiftImage {
        giftPictureUrl: string;
    }
    interface GiftDetails {
        giftImage: GiftImage;
        describe: string;
        giftType: number;
        diamondCount: number;
        giftName: string;
    }
    interface GiftExtra {
        timestamp: string;
        receiverUserId: string;
    }
    interface WebcastGiftMessageData {
        event: Event;
        giftId: number;
        repeatCount: number;
        user: User;
        groupId: string;
        giftDetails: GiftDetails;
        monitorExtra: string;
        giftExtra: GiftExtra;
    }
    interface TreasureBoxData {
        coins: number;
        canOpen: number;
        timestamp: string;
    }
    interface User4 {
        user: User;
    }
    interface User3 {
        user4: User4;
    }
    interface User2 {
        user3: User3[];
    }
    interface TreasureBoxUser {
        user2: User2;
    }
    interface Image {
        imageUrl: string;
    }
    interface EmoteData {
        emoteId: string;
        image: Image;
    }
    interface Emote {
        emote: EmoteData;
        placeInComment?: number;
    }
    interface WebcastEnvelopeMessageData {
        treasureBoxUser: TreasureBoxUser;
        treasureBoxData: TreasureBoxData;
    }
    interface WebcastControlMessageData {
        action: number;
    }
    interface WebcastSubNotifyMessageData {
        event: Event;
        user: User;
        exhibitionType: number;
        subMonth: number;
        subscribingStatus: number;
    }
    interface WebcastGiftMessage {
        type: 'WebcastGiftMessage';
        data: WebcastGiftMessageData;
    }
    interface WebcastSocialMessage {
        type: 'WebcastSocialMessage';
        data: WebcastSocialMessageData;
    }
    interface WebcastChatMessage {
        type: 'WebcastChatMessage';
        data: WebcastChatMessageData;
    }
    interface WebcastLikeMessage {
        type: 'WebcastLikeMessage';
        data: WebcastLikeMessageData;
    }
    interface WebcastRoomUserSeqMessage {
        type: 'WebcastRoomUserSeqMessage';
        data: WebcastRoomUserSeqMessageData;
    }
    interface WebcastMemberMessage {
        type: 'WebcastMemberMessage';
        data: WebcastMemberMessageData;
    }
    interface WebcastRankTextMessage {
        type: 'WebcastRankTextMessage';
    }
    interface WebcastGiftBroadcastMessage {
        type: 'WebcastGiftBroadcastMessage';
    }
    interface WebcastUnauthorizedMemberMessage {
        type: 'WebcastUnauthorizedMemberMessage';
    }
    interface WebcastMsgDetectMessage {
        type: 'WebcastMsgDetectMessage';
    }
    interface WebcastEnvelopeMessage {
        type: 'WebcastEnvelopeMessage';
        data: WebcastEnvelopeMessageData;
    }
    interface WebcastInRoomBannerMessage {
        type: 'WebcastInRoomBannerMessage';
        data: string;
    }
    interface WebcastRankUpdateMessage {
        type: 'WebcastRankUpdateMessage';
    }
    interface WebcastControlMessage {
        type: 'WebcastControlMessage';
        data: WebcastControlMessageData;
    }
    interface WebcastLinkMicMethod {
        type: 'WebcastLinkMicMethod';
    }
    interface WebcastLiveIntroMessage {
        type: 'WebcastLiveIntroMessage';
        data: any;
    }
    interface WebcastEmoteChatMessage {
        type: 'WebcastEmoteChatMessage';
        data: any;
    }
    interface WebcastSubNotifyMessage {
        type: 'WebcastSubNotifyMessage';
        data: WebcastSubNotifyMessageData;
    }
    interface WebcastQuestionNewMessage {
        type: 'WebcastQuestionNewMessage';
        data: any;
    }
    interface WebcastLinkMicBattle {
        type: 'WebcastLinkMicBattle';
        data: any;
    }
    interface WebcastLinkMicArmies {
        type: 'WebcastLinkMicArmies';
        data: any;
    }
    type Message = WebcastMemberMessage | WebcastRoomUserSeqMessage | WebcastLikeMessage | WebcastChatMessage | WebcastSocialMessage | WebcastGiftMessage | WebcastRankTextMessage | WebcastGiftBroadcastMessage | WebcastUnauthorizedMemberMessage | WebcastMsgDetectMessage | WebcastEnvelopeMessage | WebcastInRoomBannerMessage | WebcastRankUpdateMessage | WebcastControlMessage | WebcastLinkMicMethod | WebcastLiveIntroMessage | WebcastEmoteChatMessage | WebcastSubNotifyMessage | WebcastQuestionNewMessage | WebcastLinkMicBattle | WebcastLinkMicArmies;
    interface RootResponse {
        messages: Message[];
        cursor: string;
        fetchInterval: number;
        serverTimestamp: string;
        internalExt: string;
        heartbeatDuration: number;
        needAck: boolean;
    }
    interface GiftData {
        giftId: string;
        details?: GiftDetails;
        repeatCount: number;
    }
    type GiftType = 'gift' | 'social' | 'subscribe' | 'like';
    interface CommentResponse extends BaseResponse {
        isModerator: boolean;
        screenName: string;
        price?: number;
        gift?: GiftData;
        giftType?: GiftType;
        origin: any;
    }
    interface UserDetails {
        createTime: string;
        bioDescription: string;
        profilePictureUrls: string[];
    }
    interface LikeResponse {
        likeCount: number;
        totalLikeCount: number;
        userId: string;
        secUid: string;
        uniqueId: string;
        nickname: string;
        profilePictureUrl: string;
        followRole: number;
        userBadges: any[];
        userSceneTypes: any[];
        userDetails: UserDetails;
        followInfo: FollowInfo;
        isModerator: boolean;
        isNewGifter: boolean;
        isSubscriber: boolean;
        topGifterRank: any;
        gifterLevel: number;
        teamMemberLevel: number;
        msgId: string;
        createTime: string;
        displayType: string;
        label: string;
    }
    interface CountStockData {
        amount: number;
        comment: CommentResponse;
    }
}
