import { BaseResponse } from './BaseResponse';
import { Colors } from './Comment';
export declare namespace Twitch {
    interface RootResponse {
        'badge-info': string;
        'animation-id': string;
        badges: string;
        bits?: string;
        color: string;
        'display-name': string;
        emotes?: string;
        'first-msg': string;
        flags: string;
        id: string;
        mod: string;
        'room-id': string;
        subscriber: "0" | "1";
        'tmi-sent-ts': string;
        turbo: string;
        'user-id': string;
        message: string;
        'user-type': string;
        'system-msg'?: string;
        vip?: number;
    }
    interface Extensions {
        durationMilliseconds: number;
        operationName: string;
        requestID: string;
    }
    interface DisplayBadge {
        id: string;
        setID: string;
        version: string;
        title: string;
        image1x: string;
        image2x: string;
        image4x: string;
        clickAction: string;
        clickURL: string;
        __typename: string;
        description: string;
    }
    interface Self {
        friendship?: any;
        __typename: string;
    }
    interface CumulativeTenure {
        daysRemaining: number;
        months: number;
        __typename: string;
    }
    interface Gift {
        isGift: boolean;
        __typename: string;
    }
    interface SubscriptionBenefit {
        id: string;
        tier: string;
        purchasedWithPrime: boolean;
        gift: Gift;
        __typename: string;
    }
    interface Relationship {
        cumulativeTenure: CumulativeTenure;
        followedAt: Date;
        subscriptionBenefit: SubscriptionBenefit;
        __typename: string;
    }
    interface TargetUserData {
        id: string;
        login: string;
        bannerImageURL?: any;
        displayName: string;
        displayBadges: DisplayBadge[];
        profileImageURL: string;
        createdAt: Date;
        self: Self;
        __typename: string;
        relationship: Relationship;
    }
    interface ViewCardResponse {
        data: {
            targetUser: TargetUserData;
        };
        extensions: Extensions;
    }
    interface Badge {
        id: string;
        setID: string;
        version: string;
        title: string;
        image1x: string;
        image2x: string;
        image4x: string;
        clickAction: string;
        clickURL: string;
        __typename: string;
    }
    interface ClipMetadata {
        game: string;
        channel_display_name: string;
        slug: string;
        id: string;
        broadcaster_id: string;
        curator_id: string;
    }
    interface TwitchMetadata {
        clip_metadata: ClipMetadata;
    }
    interface CommuinityPointsUserMessageData {
        timestamp: string;
        redemption: Redemption;
    }
    interface CommuinityPointsUserMessage {
        type: string;
        data: CommuinityPointsUserMessageData;
    }
    interface StreamChatRoomMessageData {
        message_id: string;
        request_url: string;
        author_name: string;
        thumbnail_url: string;
        title: string;
        twitch_metadata: TwitchMetadata;
    }
    interface StreamChatRoomMessage {
        type: string;
        data: StreamChatRoomMessageData;
    }
    interface User {
        id: string;
        login: string;
        display_name: string;
    }
    interface RewardImage {
        url_1x: string;
        url_2x: string;
        url_4x: string;
    }
    interface MaxPerStream {
        is_enabled: boolean;
        max_per_stream: number;
    }
    interface MaxPerUserPerStream {
        is_enabled: boolean;
        max_per_user_per_stream: number;
    }
    interface GlobalCooldown {
        is_enabled: boolean;
        global_cooldown_seconds: number;
    }
    interface Reward {
        id: string;
        channel_id: string;
        title: string;
        prompt: string;
        cost: number;
        is_user_input_required: boolean;
        is_sub_only: boolean;
        image: RewardImage | null;
        default_image: RewardImage;
        background_color: string;
        is_enabled: boolean;
        is_paused: boolean;
        is_in_stock: boolean;
        max_per_stream: MaxPerStream;
        should_redemptions_skip_request_queue: boolean;
        template_id: any;
        updated_for_indicator_at: string;
        max_per_user_per_stream: MaxPerUserPerStream;
        global_cooldown: GlobalCooldown;
        redemptions_redeemed_current_stream: any;
        cooldown_expires_at: string;
        user_input?: string;
        reward_type?: string;
        bits_cost?: number;
        default_bits_cost?: number;
        pricing_type?: string;
    }
    interface Redemption {
        id: string;
        user: User;
        channel_id: string;
        redeemed_at: string;
        reward: Reward;
        user_input?: string;
        status: string;
        cursor: string;
    }
    interface VideoPlayBackMessage {
        type: string;
        server_time: number;
        viewers: number;
    }
    interface ChatRichEmbed {
        message_id: string;
        request_url: string;
        author_name: string;
        thumbnail_url: string;
        title: string;
        twitch_metadata: TwitchMetadata;
    }
    interface ResponseNotification {
        type: string;
        error: string;
        nonce: string;
    }
    interface Data {
        topic: string;
        message: string;
    }
    interface MetaResponse {
        type: string;
        data: Data;
    }
    interface Static {
        "1": string;
        "2": string;
        "3": string;
        "4": string;
        "1.5": string;
    }
    interface Animated {
        "1": string;
        "2": string;
        "3": string;
        "4": string;
        "1.5": string;
    }
    interface Image {
        animated: Animated;
        static: Static;
    }
    interface Images {
        dark: Image;
        light: Image;
    }
    interface Tier {
        min_bits: number;
        id: string;
        color: string;
        images: Images;
        can_cheer: boolean;
        show_in_bits_card: boolean;
    }
    interface Cheers {
        prefix: string;
        tiers: Tier[];
        type: string;
        order: number;
        last_updated: string;
        is_charitable: boolean;
    }
    interface TierConfig {
        id: string;
        bits: number;
        canShowInBitsCard: boolean;
    }
    interface Node {
        id: string;
        prefix: string;
        type: string;
        campaign: any;
        tiers: TierConfig[];
    }
    interface Group {
        templateURL: string;
        nodes: Node[];
    }
    interface CheerGlobalConfig {
        groups: Group[];
    }
    interface CheerChannelConfig {
        groups: Group[];
    }
    interface StreamRefetchManagerResponse {
        user?: {
            id: string;
            __typename: string;
            stream: null | {
                id: string;
                isEncrypted: boolean;
                __typename: string;
            };
        };
    }
    interface BitsGlobalConfig {
        cheerConfig: CheerGlobalConfig;
    }
    interface Cheer {
        id: string;
        cheerGroups: Group[];
        isEnabled: boolean;
        isBitsEnabled: boolean;
    }
    interface Channel {
        id: string;
        cheer: Cheer;
    }
    interface BitsChannelConfig {
        channel: Channel;
    }
    interface CheerEmotesResponse {
        data: Cheers[];
    }
    interface StayCommentData {
        comment: Twitch.CommentResponse;
        redemption: Twitch.Redemption;
    }
    interface CommentResponse extends BaseResponse {
        bits?: string;
        price?: number;
        unit?: string;
        paidText?: string;
        colors?: Colors;
        turbo?: string;
        flags?: string;
        animationId?: string;
        mod?: string;
        subscriber?: "0" | "1";
        isModerator: boolean;
        origin: string;
        reward?: Twitch.Reward;
        screenName: string;
    }
}
