"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.YouTubeSuperChat = exports.YouTubeComment = void 0;
const types_1 = require("./types");
const comment_1 = require("./comment");
const youtubeCommentApi = "/vc-official/onecomme/youtube/comment";
const youtubeSuperApi = "/vc-official/onecomme/youtube/super";
class YouTubeComment {
    constructor(raw) {
        this.endpoint = youtubeCommentApi;
        this.raw = raw;
    }
    getJson() {
        const obj = {
            id: this.raw.id,
            liveId: this.raw.liveId,
            userId: this.raw.userId,
            name: this.raw.name,
            isOwner: this.raw.isOwner,
            isModerator: this.raw.isModerator,
            isMember: this.raw.isMember,
            autoModerated: this.raw.autoModerated,
            timestamp: (0, types_1.toTimestamp)(this.raw.timestamp),
            hasGift: false,
            comment: (0, comment_1.normalizeEmoji)(this.raw.comment),
            displayName: this.raw.displayName
        };
        return JSON.stringify(obj);
    }
}
exports.YouTubeComment = YouTubeComment;
class YouTubeSuperChat {
    constructor(raw) {
        this.endpoint = youtubeSuperApi;
        this.raw = raw;
    }
    getJson() {
        // TODO: スーパーチャットのときのみ値があるフィールドは undefined-able になっているが、
        // このAPIを呼んでいるときは多分 undefined は来ないので型で保証したい
        const obj = {
            id: this.raw.id,
            liveId: this.raw.liveId,
            userId: this.raw.userId,
            name: this.raw.name,
            isOwner: this.raw.isOwner,
            isModerator: this.raw.isModerator,
            isMember: this.raw.isMember,
            autoModerated: this.raw.autoModerated,
            timestamp: (0, types_1.toTimestamp)(this.raw.timestamp),
            hasGift: true,
            comment: (0, comment_1.normalizeEmoji)(this.raw.comment),
            displayName: this.raw.displayName,
            paidText: this.raw.paidText,
            price: this.raw.price,
            unit: this.raw.unit,
            colors: this.convert(this.raw.colors),
            tier: this.raw.tier,
        };
        return JSON.stringify(obj);
    }
    convert(colors) {
        if (!colors)
            return undefined;
        return {
            headerBackgroundColor: (0, types_1.toColor)(colors.headerBackgroundColor),
            headerTextColor: (0, types_1.toColor)(colors.headerTextColor),
            bodyBackgroundColor: (0, types_1.toColor)(colors.bodyBackgroundColor),
            bodyTextColor: (0, types_1.toColor)(colors.bodyTextColor),
            authorNameTextColor: (0, types_1.bind)(colors.authorNameTextColor, types_1.toColor),
            timestampColor: (0, types_1.bind)(colors.timestampColor, types_1.toColor)
        };
    }
}
exports.YouTubeSuperChat = YouTubeSuperChat;
